Skip to contents

This function calculates the points expected to be gained by each team in the remainder of this Premier League season.

Usage

calc_points_expected_remaining(games_remaining)

Arguments

games_remaining

These are the remaining games, with their associated model parameters, as generated by running model_parameters_unplayed.

Examples

if (FALSE) { # \dontrun{
calc_points_expected_remaining(
  games_remaining = data_results
  )
} # }