Skip to contents

This function projects the points expected to be gained by each team across this Premier League season.

Usage

calc_points_expected_total(table_current, points_expected)

Arguments

table_current

This is the current table, as generated by running calc_table_current.

points_expected

These are the expected points per team across the rest of the season, as generated by running calc_points_expected_remaining.

Examples

if (FALSE) { # \dontrun{
calc_points_expected_total(
  table_current = data_table_current,
  points_expected = data_points_expected_remaining
  )
} # }