Skip to contents

This function takes the latest data on this Premier League season and combines it with corresponding results from previous seasons, if desired.

Usage

get_results_filtered(results, index_game_latest, lookback_rounds)

Arguments

results

These are the results from this and possibly earlier seasons, as generated by get_results.

index_game_latest

This is the index of the latest game played, which can be generated by calc_game_latest.

lookback_rounds

This is the number of rounds of fixtures to use in a model (so 38 would represent a whole season).

Examples

if (FALSE) { # \dontrun{
get_results_filtered(
  results = data_results,
  index_game_latest = 280L,
  lookback_rounds = 38L,
  )
} # }