Skip to contents

This function takes the relevant results generated in modelling the strength of the Premier League teams and extracts the relevant parameters.

Usage

model_extract_parameters(model_output)

Arguments

model_output

This is the output generated by model_run.

Examples

if (FALSE) { # \dontrun{
model_extract_parameters(
  model_output = data_model_output
  )
} # }