Skip to contents

This function takes the relevant parameters from the model and assigns them to the approapriate teams in each remaining game of the season.

Usage

model_parameters_unplayed(model_parameters, results)

Arguments

model_parameters

This is the output generated by model_extract_parameters.

results

These are the results from this and possibly earlier seasons, as generated by get_results_filtered.

Examples

if (FALSE) { # \dontrun{
model_parameters_unplayed(
  model_parameters = data_model_parameters,
  results = data_results
  )
} # }