Skip to contents

This function takes the relevant filtered results from the Premier League and combines it in a way that the R prediction model can recognise.

Usage

model_prepare_frame(results)

Arguments

results

These are the results from this and possibly earlier seasons, as generated by get_results_filtered.

Examples

if (FALSE) { # \dontrun{
model_prepare_frame(
  results = data_results
  )
} # }