Skip to contents

This function prints the latest standings of this Premier League season.

Usage

print_table_current(table_latest)

Arguments

table_latest

These are the latest standings generated by running calc_table_current.

Examples

if (FALSE) { # \dontrun{
print_table_current(
  table_latest = data_calc_table_current
  )
} # }