Skip to contents

This function takes the likelihoods of all possible standings for all clubs over this Premier League season and reformats them for improved presentation..

Usage

reformat_outcomes(value)

Arguments

value

This is the outcome value to be reformatted.

Examples

if (FALSE) { # \dontrun{
reformat_outcomes(
  value = 0.94
  )
} # }