Skip to contents

This function takes the relevant data from the simulations and the current table to the likelihoods of all possible standings for all clubs over this Premier League season.

Usage

simulate_outcomes(data_standings_simulations, value_number_sims)

Arguments

data_standings_simulations

These are the standings for each club in each scenario run, as generated by simulate_standings.

value_number_sims

This is the number of simulations to use for each game in the remaining season. Defaults to 50,000.

Examples

if (FALSE) { # \dontrun{
simulate_outcomes(
  data_standings_simulations = data_standings_simulations,
  value_number_sims = 1000000
  )
} # }