Skip to contents

This function takes the relevant data from the simulations and finds the standings for each team at the end of the season.

Usage

simulate_standings(data_game_simulations, data_table_latest)

Arguments

data_game_simulations

These are the outcome scenarios of the unplayed games in this Premier League season, as generated by simulate_games.

data_table_latest

These are the latest standings generated by running calc_table_current.

Examples

if (FALSE) { # \dontrun{
simulate_standings(
  data_game_simulations = data_game_simulations,
  data_table_latest = data_table_latest
  )
} # }