Skip to contents

A dataset containing the teams in the latest Premier League season.

Usage

teams

Format

A data frame with 20 rows (one for each team) and 4 variables:

teamName

The long name of the team in question, used in footballData

shortName

The three-letter code of the team in question

midName

The more-readable name of the team in question

openName

The more-readable name of the team in question, used in openData