Get the latest available results for the Premier League in a given season
Source:R/get_footballData.R
get_footballData.RdThis function retrieves the latest data on the Premier League results for a given season.
Arguments
- value_link
This is the link for the data on the web. For example, you could use 'https://www.football-data.co.uk/mmz4281/2526/E0.csv'.
- table_schedule
This is the location of the schedule data, as generated through an in-built dataset or by using
get_openData_schedule.- table_teams
These are the teams in the season's Premier League, available as the
teamsdataset in this package.- value_yearEnd
This is the integer required as the year in which the season ends.