This function takes the latest data on this Premier League season and combines it with corresponding results from previous seasons, if desired.
Arguments
- results_thisSeason
These are the results generated by running
get_openDataon the current season, such as at 'https://raw.githubusercontent.com/openfootball/football.json/refs/heads/master/2024-25/en.1.json'.- seasons
This is the integer required for the number of previous seasons to include. It defaults to zero.