Assign the model parameters for unplayed games in this Premier League season.
Source:R/model_parameters_unplayed.R
model_parameters_unplayed.RdThis function takes the relevant parameters from the model and assigns them to the approapriate teams in each remaining game of the season.