Prepare the modelframe in order to run the prediction model
Source:R/model_prepare_frame.R
model_prepare_frame.RdThis function takes the relevant filtered results from the Premier League and combines it in a way that the R prediction model can recognise.