Print the current table for this Premier League season
Source:R/print_table_current.R
print_table_current.RdThis function prints the latest standings of this Premier League season.

R/print_table_current.R
print_table_current.RdThis function prints the latest standings of this Premier League season.