Simulate the standings over this Premier League season.
Source:R/simulate_standings.R
simulate_standings.RdThis function takes the relevant data from the simulations and finds the standings for each team at the end of the season.

R/simulate_standings.R
simulate_standings.RdThis function takes the relevant data from the simulations and finds the standings for each team at the end of the season.